# scans2any

IP-Addresses | Hostnames | Ports | Services | Banners | OS
--- | --- | --- | --- | --- | ---
192.168.56.10 | kingslanding.sevenkingdoms.local | 53/tcp 80/tcp 88/tcp 135/tcp 139/tcp 389/tcp 445/tcp 464/tcp 593/tcp 636/tcp 3268/tcp 3269/tcp 3389/tcp 5985/tcp 5986/tcp | domain http kerberos-sec msrpc netbios-ssn ldap microsoft-ds kpasswd5 ncacn_http ldap ldap ldap ms-wbt-server http http | Simple DNS Plus Microsoft IIS httpd/10.0 Microsoft Windows Kerberos Microsoft Windows RPC Microsoft Windows netbios-ssn Microsoft Windows Active Directory LDAP Microsoft Windows RPC over HTTP/1.0 Microsoft Windows Active Directory LDAP Microsoft Windows Active Directory LDAP Microsoft Windows Active Directory LDAP Microsoft Terminal Services Microsoft HTTPAPI httpd/2.0 Microsoft HTTPAPI httpd/2.0 | windows
192.168.56.11 | winterfell.north.sevenkingdoms.local | 53/tcp 88/tcp 135/tcp 139/tcp 389/tcp 445/tcp 464/tcp 593/tcp 636/tcp 3268/tcp 3269/tcp 3389/tcp 5985/tcp 5986/tcp | domain kerberos-sec msrpc netbios-ssn ldap microsoft-ds kpasswd5 ncacn_http ldap ldap ldap ms-wbt-server http http | Simple DNS Plus Microsoft Windows Kerberos Microsoft Windows RPC Microsoft Windows netbios-ssn Microsoft Windows Active Directory LDAP Microsoft Windows RPC over HTTP/1.0 Microsoft Windows Active Directory LDAP Microsoft Windows Active Directory LDAP Microsoft Windows Active Directory LDAP Microsoft Terminal Services Microsoft HTTPAPI httpd/2.0 Microsoft HTTPAPI httpd/2.0 | windows
192.168.56.22 | castelblack.north.sevenkingdoms.local | 80/tcp 135/tcp 139/tcp 445/tcp 1433/tcp 3389/tcp 5985/tcp 5986/tcp | http msrpc netbios-ssn microsoft-ds ms-sql-s ms-wbt-server http http | Microsoft IIS httpd/10.0 Microsoft Windows RPC Microsoft Windows netbios-ssn Microsoft SQL Server 2019/15.00.2000.00; RTM Microsoft Terminal Services Microsoft HTTPAPI httpd/2.0 Microsoft HTTPAPI httpd/2.0 | windows